@@ -22,6 +22,7 @@ package org.apache.bookkeeper.bookie.storage.ldb;
 
 import com.google.common.base.Predicate;
 import com.google.common.collect.Iterables;
+import com.google.common.collect.Sets;
 import com.google.protobuf.ByteString;
 import io.netty.buffer.ByteBuf;
 import java.io.Closeable;
@@ -29,6 +30,7 @@ import java.io.IOException;
 import java.util.AbstractMap.SimpleEntry;
 import java.util.Arrays;
 import java.util.Map.Entry;
+import java.util.Set;
 import java.util.concurrent.ConcurrentLinkedQueue;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.locks.ReentrantLock;
@@ -63,7 +65,7 @@ public class LedgerMetadataIndex implements Closeable {
     private final ConcurrentLinkedQueue<Entry<Long, LedgerData>> pendingLedgersUpdates;
 
     // Holds ledger ids that were delete from memory map, and pending to be flushed on db
-    private final ConcurrentLinkedQueue<Long> pendingDeletedLedgers;
+    private final Set<Long> pendingDeletedLedgers;
     private final ReentrantLock[] locks = new ReentrantLock[16];
 
     public LedgerMetadataIndex(ServerConfiguration conf, KeyValueStorageFactory storageFactory, String basePath,
@@ -90,7 +92,7 @@ public class LedgerMetadataIndex implements Closeable {
         }
 
         this.pendingLedgersUpdates = new ConcurrentLinkedQueue<Entry<Long, LedgerData>>();
-        this.pendingDeletedLedgers = new ConcurrentLinkedQueue<Long>();
+        this.pendingDeletedLedgers = Sets.newConcurrentHashSet();
 
         this.stats = new LedgerMetadataIndexStats(
             stats,
@@ -295,41 +297,55 @@ public class LedgerMetadataIndex implements Closeable {
      * Flushes all pending changes.
      */
     public void flush() throws IOException {
+        if (pendingLedgersUpdates.isEmpty()) {
+            return;
+        }
+
         LongWrapper key = LongWrapper.get();
 
-        int updatedLedgers = 0;
-        Entry<Long, LedgerData> entry;
-        while ((entry = pendingLedgersUpdates.poll()) != null) {
-            key.set(entry.getKey());
-            byte[] value = entry.getValue().toByteArray();
-            ledgersDb.put(key.array, value);
-            ++updatedLedgers;
-        }
+        try {
+            int updatedLedgers = 0;
+            Entry<Long, LedgerData> entry;
+            while ((entry = pendingLedgersUpdates.poll()) != null) {
+                key.set(entry.getKey());
+                byte[] value = entry.getValue().toByteArray();
+                ledgersDb.put(key.array, value);
+                ++updatedLedgers;
+            }
 
-        if (log.isDebugEnabled()) {
-            log.debug("Persisting updates to {} ledgers", updatedLedgers);
-        }
+            if (log.isDebugEnabled()) {
+                log.debug("Persisting updates to {} ledgers", updatedLedgers);
+            }
 
-        ledgersDb.sync();
-        key.recycle();
+            ledgersDb.sync();
+        } finally {
+            key.recycle();
+        }
     }
 
     public void removeDeletedLedgers() throws IOException {
+        if (pendingDeletedLedgers.isEmpty()) {
+            return;
+        }
+
         LongWrapper key = LongWrapper.get();
 
-        int deletedLedgers = 0;
-        Long ledgerId;
-        while ((ledgerId = pendingDeletedLedgers.poll()) != null) {
-            key.set(ledgerId);
-            ledgersDb.delete(key.array);
-        }
+        try {
+            int deletedLedgers = 0;
+            for (Long ledgerId : pendingDeletedLedgers) {
+                key.set(ledgerId);
+                ledgersDb.delete(key.array);
+                ++deletedLedgers;
+            }
 
-        if (log.isDebugEnabled()) {
-            log.debug("Persisting deletes of ledgers {}", deletedLedgers);
-        }
+            if (log.isDebugEnabled()) {
+                log.debug("Persisting deletes of ledgers {}", deletedLedgers);
+            }
 
-        ledgersDb.sync();
-        key.recycle();
+            ledgersDb.sync();
+        } finally {
+            key.recycle();
+        }
     }
 
     private ReentrantLock lockForLedger(long ledgerId) {
@@ -392,6 +408,7 @@ public class LedgerMetadataIndex implements Closeable {
 
             if (ledgers.put(ledgerId, newLedgerData) == null) {
                 // Ledger had been deleted
+                ledgersCount.incrementAndGet();
                 return;
             } else if (log.isDebugEnabled()) {
                 log.debug("Set explicitLac on ledger {}", ledgerId);
